@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Lzd - Educational decompressor for the lzip format
-# Copyright (C) 2013-2024 Antonio Diaz Diaz.
+# Copyright (C) 2013-2025 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -30,8 +30,9 @@ cd "${objdir}"/tmp || framework_failure
 
 in="${testdir}"/test.txt
 in_lz="${testdir}"/test.txt.lz
-in_em="${testdir}"/test_em.txt.lz
+em_lz="${testdir}"/em.lz
 fox_lz="${testdir}"/fox.lz
+fnz_lz="${testdir}"/fox_nz.lz
 fail=0
 test_failed() { fail=1 ; printf " $1" ; [ -z "$2" ] || printf "($2)" ; }
 
@@ -40,10 +41,8 @@ printf "testing lzd-%s..." "$2"
 "${LZIP}" < "${in}" 2> /dev/null
 [ $? = 2 ] || test_failed $LINENO
 
-for i in "${in_lz}" "${in_em}" ; do
-	"${LZIP}" < "$i" > out || test_failed $LINENO "$i"
-	cmp "${in}" out || test_failed $LINENO "$i"
-done
+"${LZIP}" < "${in_lz}" > out || test_failed $LINENO
+cmp "${in}" out || test_failed $LINENO
 
 cat "${in}" "${in}" > in2 || framework_failure
 cat "${in_lz}" "${in_lz}" | "${LZIP}" > out2 || test_failed $LINENO
@@ -56,9 +55,27 @@ printf "\ngarbage" >> out2.lz || framework_failure
 cmp in2 out2 || test_failed $LINENO
 rm -f in2 out2 out2.lz || framework_failure
 
+touch empty || framework_failure
+"${LZIP}" -d < "${em_lz}" > em || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+
 printf "\ntesting bad input..."
 
-for i in fox_bm.lz fox_v2.lz fox_s11.lz fox_de20.lz \
+cat "${em_lz}" "${em_lz}" | "${LZIP}" -d > em 2> /dev/null
+[ $? = 2 ] || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+rm -f empty em || framework_failure
+cat "${em_lz}" "${in_lz}" | "${LZIP}" -d > out 2> /dev/null
+[ $? = 2 ] || test_failed $LINENO
+cmp "${in}" out || test_failed $LINENO
+cat "${in_lz}" "${em_lz}" | "${LZIP}" -d > out 2> /dev/null
+[ $? = 2 ] || test_failed $LINENO
+cmp "${in}" out || test_failed $LINENO
+
+"${LZIP}" < "${fnz_lz}" 2> /dev/null
+[ $? = 2 ] || test_failed $LINENO
+
+for i in fox_v2.lz fox_s11.lz fox_de20.lz \
          fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
 	"${LZIP}" < "${testdir}"/$i > /dev/null 2>&1
 	[ $? = 2 ] || test_failed $LINENO $i
@@ -70,24 +87,24 @@ for i in fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
 	[ $? = 2 ] || test_failed $LINENO $i
 	cmp fox out || test_failed $LINENO $i
 done
-rm -f fox out || framework_failure
+rm -f fox || framework_failure
 
 cat "${in_lz}" "${in_lz}" > in2.lz || framework_failure
 cat "${in_lz}" "${in_lz}" "${in_lz}" > in3.lz || framework_failure
-if dd if=in3.lz of=trunc.lz bs=14752 count=1 2> /dev/null &&
-   [ -e trunc.lz ] && cmp in2.lz trunc.lz > /dev/null 2>&1 ; then
+if dd if=in3.lz of=trunc.lz bs=14682 count=1 2> /dev/null &&
+   [ -e trunc.lz ] && cmp in2.lz trunc.lz ; then
 # can't detect truncated header of non-first member
-	for i in 6 20 14734 14758 ; do
+	for i in 6 20 14664 14688 ; do
 		dd if=in3.lz of=trunc.lz bs=$i count=1 2> /dev/null
 		"${LZIP}" < trunc.lz > /dev/null 2>&1
 		[ $? = 2 ] || test_failed $LINENO $i
 	done
 else
-	printf "\nwarning: skipping truncation test: 'dd' does not work on your system."
+	printf "warning: skipping truncation test: 'dd' does not work on your system."
 fi
 rm -f in2.lz in3.lz trunc.lz || framework_failure
 
-cat "${in_lz}" > ingin.lz || framework_failure
+cp "${in_lz}" ingin.lz || framework_failure
 printf "g" >> ingin.lz || framework_failure
 cat "${in_lz}" >> ingin.lz || framework_failure
 "${LZIP}" -d < ingin.lz > out || test_failed $LINENO
